@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mowie" "0.1.1"
+(define-package "mowie" "20250113.122"
   "Cycle Through Point-Moving Commands."
   '((emacs "28.1"))
   :url "https://codeberg.org/mekeor/mowie"
-  :commit "7b826c751014a294b493a6bfebe1cda6a1832ab0"
-  :revdesc "7b826c751014"
+  :commit "26f605cf632579af897a85a3922bf17fac616519"
+  :revdesc "26f605cf6325"
   :keywords '("convenience")
   :authors '(("Mekeor Melire" . "mekeor@posteo.de"))
   :maintainers '(("Mekeor Melire" . "mekeor@posteo.de")))
